#[non_exhaustive]
pub enum ErrorKind {
Bind(Error),
Io(Error),
Config(Error),
Collisions(Collisions),
FailedFairings(Vec<Info>),
SentinelAborts(Vec<Sentry>),
InsecureSecretKey(Profile),
Shutdown(Arc<Rocket<Orbit>>, Option<Box<dyn StdError + Send + Sync>>),
}Expand description
The kind error that occurred.
In almost every instance, a launch error occurs because of an I/O error;
this is represented by the Io variant. A launch error may also occur
because of ill-defined routes that lead to collisions or because a fairing
encountered an error; these are represented by the Collision and
FailedFairing variants, respectively.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Bind(Error)
Binding to the provided address/port failed.
Io(Error)
An I/O error occurred during launch.
Config(Error)
A valid Config could not be extracted from the
configured figment.
Collisions(Collisions)
Route collisions were detected.
FailedFairings(Vec<Info>)
Launch fairing(s) failed.
SentinelAborts(Vec<Sentry>)
Sentinels requested abort.
InsecureSecretKey(Profile)
The configuration profile is not debug but not secret key is configured.
Shutdown(Arc<Rocket<Orbit>>, Option<Box<dyn StdError + Send + Sync>>)
Tuple Fields
Shutdown failed.